@@ -2,7 +2,7 @@
 /*
  * gog-axis-line.c :
  *
- * Copyright (C) 2005 Emmanuel Pacaud (emmanuel.pacaud@univ-poitiers.fr)
+ * Copyright (C) 2005-2007 Emmanuel Pacaud (emmanuel.pacaud@univ-poitiers.fr)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -24,11 +24,12 @@
 #include <goffice/graph/gog-axis-line-impl.h>
 #include <goffice/graph/gog-axis.h>
 #include <goffice/graph/gog-chart.h>
+#include <goffice/graph/gog-chart-map.h>
 #include <goffice/graph/gog-data-allocator.h>
 #include <goffice/graph/gog-renderer.h>
 #include <goffice/graph/gog-style.h>
 #include <goffice/graph/gog-theme.h>
-#include <goffice/utils/go-math.h>
+#include <goffice/math/go-math.h>
 
 #include <gsf/gsf-impl-utils.h>
 
@@ -52,6 +53,7 @@ static GObjectClass *gab_parent_klass;
 enum {
 	AXIS_BASE_PROP_0,
 	AXIS_BASE_PROP_POSITION,
+	AXIS_BASE_PROP_POSITION_STR,
 	AXIS_BASE_PROP_MAJOR_TICK_LABELED,
 	AXIS_BASE_PROP_MAJOR_TICK_IN,
 	AXIS_BASE_PROP_MAJOR_TICK_OUT,
@@ -78,6 +80,11 @@ gog_axis_base_set_property (GObject *obj, guint param_id,
 
 	switch (param_id) {
 		case AXIS_BASE_PROP_POSITION:
+			position = g_value_get_uint (value);
+			resized = (position != axis_base->pos_user);
+			gog_axis_base_set_position (axis_base, position);
+			break;
+		case AXIS_BASE_PROP_POSITION_STR:
 			str = g_value_get_string (value);
 			if (str == NULL)
 				return;
@@ -89,8 +96,8 @@ gog_axis_base_set_property (GObject *obj, guint param_id,
 				position = GOG_AXIS_AT_HIGH;
 			else
 				return;
-			resized = (position != axis_base->position);
-			axis_base->position = position;
+			resized = (position != axis_base->pos_user);
+			axis_base->pos_user = position;
 			break;
 		case AXIS_BASE_PROP_CROSS_AXIS_ID:
 			axis_base->crossed_axis_id = g_value_get_uint (value);
@@ -162,7 +169,11 @@ gog_axis_base_get_property (GObject *obj, guint param_id,
 
 	switch (param_id) {
 		case AXIS_BASE_PROP_POSITION:
-			switch (axis_base->position) {
+			g_value_set_uint (value, axis_base->pos_user);
+			break;
+
+		case AXIS_BASE_PROP_POSITION_STR:
+			switch (axis_base->pos_user) {
 				case GOG_AXIS_AT_LOW:
 					g_value_set_static_string (value, "low");
 					break;
@@ -249,6 +260,9 @@ gog_axis_base_get_crossed_axis_type (GogAxisBase *axis_base)
 	axis_set = gog_chart_get_axis_set (axis_base->chart);
 
 	crossed_type = GOG_AXIS_UNKNOWN;
+	if (axis_set == GOG_AXIS_SET_UNKNOWN)
+		return crossed_type;
+
 	switch (axis_set & GOG_AXIS_SET_FUNDAMENTAL) {
 		case GOG_AXIS_SET_XY:
 			if (axis_type == GOG_AXIS_X)
@@ -263,7 +277,6 @@ gog_axis_base_get_crossed_axis_type (GogAxisBase *axis_base)
 				crossed_type = GOG_AXIS_RADIAL;
 			break;
 		case GOG_AXIS_SET_X:
-		case GOG_AXIS_SET_UNKNOWN:
 			break;
 		case GOG_AXIS_SET_XYZ:
 		case GOG_AXIS_SET_ALL:
@@ -346,7 +359,7 @@ gog_axis_base_set_position (GogAxisBase *axis_base, GogAxisPosition position)
 			position = GOG_AXIS_CROSS;
 	}
 
-	axis_base->position = position;
+	axis_base->pos_calculated = position;
 }
 
 #ifdef GOFFICE_WITH_GTK
@@ -407,7 +420,7 @@ cb_position_toggled (GtkWidget *button, AxisBasePrefs *state)
 	else
 		position = GOG_AXIS_AT_LOW;
 
-	if (position != axis_base->position)
+	if (position != axis_base->pos_user)
 		gtk_widget_set_sensitive (glade_xml_get_widget (state->gui, "padding_spinbutton"),
 					  position != GOG_AXIS_CROSS);
 
@@ -543,17 +556,17 @@ gog_axis_base_populate_editor (GogObject *gobj,
 					"state", state, (GDestroyNotify) axis_base_pref_free);
 
 		w = glade_xml_get_widget (gui, "axis_low");
-		if (axis_base->position == GOG_AXIS_AT_LOW)
+		if (axis_base->pos_user == GOG_AXIS_AT_LOW)
 			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), TRUE);
 		g_signal_connect (G_OBJECT (w), "toggled",
 				  G_CALLBACK (cb_position_toggled), state);
 		w = glade_xml_get_widget (gui, "axis_cross");
-		if (axis_base->position == GOG_AXIS_CROSS)
+		if (axis_base->pos_user == GOG_AXIS_CROSS)
 			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), TRUE);
 		g_signal_connect (G_OBJECT (w), "toggled",
 				  G_CALLBACK (cb_position_toggled), state);
 		w = glade_xml_get_widget (gui, "axis_high");
-		if (axis_base->position == GOG_AXIS_AT_HIGH)
+		if (axis_base->pos_user == GOG_AXIS_AT_HIGH)
 			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), TRUE);
 		g_signal_connect (G_OBJECT (w), "toggled",
 				  G_CALLBACK (cb_position_toggled), state);
@@ -571,7 +584,7 @@ gog_axis_base_populate_editor (GogObject *gobj,
 		gtk_spin_button_set_value (GTK_SPIN_BUTTON (w), axis_base->padding);
 		g_signal_connect (G_CALLBACK (w), "value-changed",
 				  G_CALLBACK (cb_padding_changed), axis_base);
-		gtk_widget_set_sensitive (w, axis_base->position != GOG_AXIS_CROSS);
+		gtk_widget_set_sensitive (w, axis_base->pos_user != GOG_AXIS_CROSS);
 		hide_position_box = FALSE;
 	} else {
 		w = glade_xml_get_widget (gui, "padding_box");
@@ -629,9 +642,15 @@ gog_axis_base_class_init (GObjectClass *gobject_klass)
 	gog_klass->parent_changed 	= gog_axis_base_parent_changed;
 
 	g_object_class_install_property (gobject_klass, AXIS_BASE_PROP_POSITION,
-		g_param_spec_string ("pos-str", 
+		g_param_spec_uint ("pos", 
 			_("Axis position"),
 			_("Where to position an axis low, high, or crossing"),
+			GOG_AXIS_AT_LOW, GOG_AXIS_AUTO, GOG_AXIS_AT_LOW, 
+			GSF_PARAM_STATIC | G_PARAM_READWRITE));
+	g_object_class_install_property (gobject_klass, AXIS_BASE_PROP_POSITION_STR,
+		g_param_spec_string ("pos-str", 
+			_("Axis position (as a string)"),
+			_("Where to position an axis low, high, or crossing"),
 			"low", 
 			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, AXIS_BASE_PROP_MAJOR_TICK_LABELED,
@@ -705,7 +724,7 @@ gog_axis_base_init (GogAxisBase *gab)
 	gab->chart = NULL;
 	gab->axis = NULL;
 
-	gab->position = GOG_AXIS_AT_LOW;
+	gab->pos_user = gab->pos_calculated = GOG_AXIS_AT_LOW;
 	gab->crossed_axis_id = 0;
 
 	gab->minor.tick_in = gab->minor.tick_out = gab->major.tick_in = FALSE;
@@ -734,13 +753,13 @@ gog_axis_base_get_position (GogAxisBase *axis_base)
 {
 	g_return_val_if_fail (GOG_AXIS_BASE (axis_base) != NULL, GOG_AXIS_AT_LOW);
 
-	return axis_base->position;
+	return axis_base->pos_calculated;
 }
 
 static int
 gog_axis_base_get_padding (GogAxisBase *axis_base)
 {
-	return (axis_base->position == GOG_AXIS_CROSS ?
+	return (axis_base->pos_calculated == GOG_AXIS_CROSS ?
 		0 : axis_base->padding);
 }
 
@@ -774,11 +793,8 @@ gog_tool_select_axis_point (GogView *view, double x, double y, GogObject **gobj)
 static void
 gog_tool_select_axis_render (GogView *view)
 {
-	if (gog_tool_bound_is_valid_axis (view)) {
-		ArtVpath *path = gog_renderer_get_rectangle_vpath (&view->allocation);
-		gog_renderer_draw_sharp_path (view->renderer, path);
-		art_free (path);
-	}
+	if (gog_tool_bound_is_valid_axis (view))
+		gog_renderer_draw_selection_rectangle (view->renderer, &view->allocation);
 }
 
 static GogTool gog_axis_tool_select_axis = {
@@ -975,7 +991,7 @@ axis_line_get_bbox (GogAxisBase *axis_base, GogRenderer *renderer,
 	gog_renderer_get_text_OBR (renderer, "0", TRUE, &txt_obr);
 	label_padding = txt_obr.w;
 
-	total_bbox.x = x; total_bbox.y = y; 
+	total_bbox.x = x; total_bbox.y = y;
 	total_bbox.w = w; total_bbox.h = h;
 	bbox.x = x -= gog_renderer_pt2r_x (renderer, padding * cos_alpha);
 	bbox.y = y -= gog_renderer_pt2r_y (renderer, padding * sin_alpha);
@@ -1023,7 +1039,7 @@ axis_line_get_bbox (GogAxisBase *axis_base, GogRenderer *renderer,
 			    || obr->h > label_size_max) {
 				label_size_max = MAX (obr->w, obr->h);
 				label_anchor = go_geometry_calc_label_anchor (obr, axis_angle);
-			}					
+			}
 		}
 	}
 
@@ -1032,7 +1048,7 @@ axis_line_get_bbox (GogAxisBase *axis_base, GogRenderer *renderer,
 			GOGeometryOBR *obr = obrs + i;
 			pos = gog_axis_map_to_view (map, ticks[i].position);
 			obr->w += label_padding;
-			go_geometry_calc_label_position (obr, axis_angle, tick_len, 
+			go_geometry_calc_label_position (obr, axis_angle, tick_len,
 							 side, label_anchor);
 			obr->x += x + pos * cos (axis_angle);
 			obr->y += y + pos * sin (axis_angle);
@@ -1048,7 +1064,7 @@ axis_line_get_bbox (GogAxisBase *axis_base, GogRenderer *renderer,
 }
 
 static void
-axis_line_render (GogAxisBase *axis_base, 
+axis_line_render (GogAxisBase *axis_base,
 		  GogAxisBaseView *axis_base_view,
 		  GogRenderer *renderer,
 		  double x, double y, double w, double h,
@@ -1063,7 +1079,7 @@ axis_line_render (GogAxisBase *axis_base,
 	GOGeometryOBR zero_obr;
 	GOGeometryOBR *obrs = NULL;
 	GOGeometrySide label_anchor = GO_SIDE_AUTO;
-	ArtVpath path[3];
+	GOPath *path = NULL;
 	double line_width;
 	double axis_length, axis_angle, label_padding;
 	double major_tick_len, minor_tick_len, tick_len;
@@ -1080,31 +1096,24 @@ axis_line_render (GogAxisBase *axis_base,
 	go_geometry_cartesian_to_polar (w, h, &axis_length, &axis_angle);
 	cos_alpha = side == GO_SIDE_LEFT ? - sin (axis_angle) : + sin (axis_angle);
 	sin_alpha = side == GO_SIDE_LEFT ? + cos (axis_angle) : - cos (axis_angle);
-	
+
 	x -= gog_renderer_pt2r_x (renderer, padding * cos_alpha);
 	y -= gog_renderer_pt2r_y (renderer, padding * sin_alpha);
-	
+
 	axis_base_view->x_start = x;
 	axis_base_view->y_start = y;
 	axis_base_view->x_stop = x + w;
-	axis_base_view->y_stop = y + h;	
+	axis_base_view->y_stop = y + h;
 
 	is_line_visible = gog_style_is_line_visible (style);
 	line_width = gog_renderer_line_size (renderer, style->line.width) / 2;
+
 	if (is_line_visible)
 	{
-		path[0].code = ART_MOVETO;
-		path[1].code = ART_LINETO;
-		path[2].code = ART_END;
-
-		path[0].x = x;
-		path[0].y = y;
-		path[1].x = path[0].x + w;
-		path[1].y = path[0].y + h;
-		if (sharp)
-			gog_renderer_draw_sharp_path (renderer, path);
-		else
-			gog_renderer_draw_path (renderer, path);
+		path = go_path_new ();
+		go_path_set_options (path, sharp ? GO_PATH_OPTIONS_SHARP : 0);
+		go_path_move_to (path, x, y);
+		go_path_line_to (path, x + w, y + h);
 	}
 
 	map = gog_axis_map_new (axis_base->axis, 0., axis_length);
@@ -1141,7 +1150,7 @@ axis_line_render (GogAxisBase *axis_base,
 				    || obr->h > label_size_max) {
 					label_size_max = MAX (obr->w, obr->h);
 					label_anchor = go_geometry_calc_label_anchor (obr, axis_angle);
-				}					
+				}
 			}
 		}
 	}
@@ -1158,27 +1167,19 @@ axis_line_render (GogAxisBase *axis_base,
 			switch (ticks[i].type) {
 				case GOG_AXIS_TICK_MAJOR:
 					if (draw_major) {
-						path[0].x = major_out_x + pos_x;
-						path[1].x = major_in_x + pos_x;
-						path[0].y = major_out_y + pos_y;
-						path[1].y = major_in_y + pos_y;
-						if (sharp)
-							gog_renderer_draw_sharp_path (renderer, path);
-						else
-							gog_renderer_draw_path (renderer, path);
+						go_path_move_to (path, major_out_x + pos_x,
+								 major_out_y + pos_y);
+						go_path_line_to (path, major_in_x + pos_x,
+								 major_in_y + pos_y);
 					}
 					break;
 
 				case GOG_AXIS_TICK_MINOR:
 					if (draw_minor) {
-						path[0].x = minor_out_x + pos_x;
-						path[1].x = minor_in_x + pos_x;
-						path[0].y = minor_out_y + pos_y;
-						path[1].y = minor_in_y + pos_y;
-						if (sharp)
-							gog_renderer_draw_sharp_path (renderer, path);
-						else
-							gog_renderer_draw_path (renderer, path);
+						go_path_move_to (path, minor_out_x + pos_x,
+								 minor_out_y + pos_y);
+						go_path_line_to (path, minor_in_x + pos_x,
+								 minor_in_y + pos_y);
 					}
 					break;
 
@@ -1191,7 +1192,7 @@ axis_line_render (GogAxisBase *axis_base,
 			GOGeometryOBR *obr = obrs + i;
 			pos = gog_axis_map_to_view (map, ticks[i].position);
 			obr->w += label_padding;
-			go_geometry_calc_label_position (obr, axis_angle, tick_len, 
+			go_geometry_calc_label_position (obr, axis_angle, tick_len,
 							 side, label_anchor);
 			obr->x += x + pos * cos (axis_angle);
 			obr->y += y + pos * sin (axis_angle);
@@ -1201,6 +1202,11 @@ axis_line_render (GogAxisBase *axis_base,
 		}
 	}
 
+	if (is_line_visible) {
+		gog_renderer_stroke_shape (renderer, path);
+		go_path_free (path);
+	}
+
 	/*
 	 * This is far from perfect, but at least things are regular.
 	 * The axis really needs to be queried to figure this out,
@@ -1330,10 +1336,11 @@ axis_circle_render (GogAxisBase *axis_base, GogRenderer *renderer,
 	GogChartMapPolarData *parms = gog_chart_map_get_polar_parms (c_map);
 	GOGeometryOBR txt_obr, txt_obr_old = {0., 0., 0., 0., 0.};
 	GOGeometryOBR txt_obr_first;
-	ArtVpath *cpath, path[3];
+	GOPath *path;
 	double angle, offset, position, label_padding;
 	double start, stop;
 	double major_tick_len, minor_tick_len, tick_len;
+	double x0, y0, x1, y1;
 	unsigned i, step_nbr, tick_nbr;
 	gboolean draw_major, draw_minor;
 	gboolean is_line_visible;
@@ -1343,34 +1350,26 @@ axis_circle_render (GogAxisBase *axis_base, GogRenderer *renderer,
 	gog_axis_map_get_extents (map, &offset , &position);
 	map = gog_chart_map_get_axis_map (c_map, 0);
 
+	path = go_path_new ();
+
 	if (is_discrete) {
 		gog_axis_map_get_extents (map, &start, &stop);
 		step_nbr = go_rint (parms->th1 - parms->th0) + 1;
-		cpath = art_new (ArtVpath, step_nbr + 2);
 		for (i = 0; i <= step_nbr; i++) {
-			gog_chart_map_2D_to_view (c_map, i + parms->th0, 
-						  position, &cpath[i].x, &cpath[i].y);
-			cpath[i].code = ART_LINETO;
+			gog_chart_map_2D_to_view (c_map, i + parms->th0, position, &x0, &y0);
+			if (i == 0)
+				go_path_move_to (path, x0, y0);
+			else
+				go_path_line_to (path, x0, y0);
 		}
-		cpath[0].code = ART_MOVETO;
-		cpath[step_nbr + 1].code = ART_END;
-		gog_renderer_draw_path (renderer, cpath);
-		g_free (cpath);
-	} else {
-		gog_renderer_draw_arc (renderer, parms->cx, parms->cy, parms->rx, parms->ry,
-				      -parms->th1, -parms->th0);
-	}
+	} else
+		go_path_arc (path, parms->cx, parms->cy, parms->rx, parms->ry,
+			     -parms->th1, -parms->th0);
 
 	is_line_visible = gog_style_is_line_visible (axis_base->base.style);
 	draw_major = axis_base->major.tick_in || axis_base->major.tick_out;
 	draw_minor = axis_base->minor.tick_in || axis_base->minor.tick_out;
 
-	if (is_line_visible) {
-		path[0].code = ART_MOVETO;
-		path[1].code = ART_LINETO;
-		path[2].code = ART_END;
-	}
-
 	minor_tick_len = gog_renderer_pt2r (renderer, axis_base->minor.size_pts);
 	major_tick_len = gog_renderer_pt2r (renderer, axis_base->major.size_pts);
 	tick_len = axis_base->major.tick_out ? major_tick_len :
@@ -1386,38 +1385,40 @@ axis_circle_render (GogAxisBase *axis_base, GogRenderer *renderer,
 				case GOG_AXIS_TICK_MAJOR:
 					if (draw_major) {
 						gog_chart_map_2D_to_view (c_map, ticks[i].position, position,
-									  &path[0].x, &path[0].y);
+									  &x0, &y0);
 						if (axis_base->major.tick_in) {
-							path[1].x = path[0].x - major_tick_len * cos (angle);
-							path[1].y = path[0].y - major_tick_len * sin (angle);
+							x1 = x0 - major_tick_len * cos (angle);
+							y1 = y0 - major_tick_len * sin (angle);
 						} else {
-							path[1].x = path[0].x;
-							path[1].y = path[0].y;
+							x1 = x0;
+							y1 = y0;
 						}
 						if (axis_base->major.tick_out) {
-							path[0].x += major_tick_len * cos (angle);
-							path[0].y += major_tick_len * sin (angle);
+							x0 += major_tick_len * cos (angle);
+							y0 += major_tick_len * sin (angle);
 						}
-						gog_renderer_draw_path (renderer, path);
+						go_path_move_to (path, x0, y0);
+						go_path_line_to (path, x1, y1);
 					}
 					break;
 
 				case GOG_AXIS_TICK_MINOR:
 					if (draw_minor) {
 						gog_chart_map_2D_to_view (c_map, ticks[i].position, position,
-									  &path[0].x, &path[0].y);
+									  &x0, &y0);
 						if (axis_base->minor.tick_in) {
-							path[1].x = path[0].x - minor_tick_len * cos (angle);
-							path[1].y = path[0].y - minor_tick_len * sin (angle);
+							x1 = x0 - minor_tick_len * cos (angle);
+							y1 = y0 - minor_tick_len * sin (angle);
 						} else {
-							path[1].x = path[0].x;
-							path[1].y = path[0].y;
+							x1 = x0;
+							y1 = y0;
 						}
 						if (axis_base->minor.tick_out) {
-							path[0].x += minor_tick_len * cos (angle);
-							path[0].y += minor_tick_len * sin (angle);
+							x0 += minor_tick_len * cos (angle);
+							y0 += minor_tick_len * sin (angle);
 						}
-						gog_renderer_draw_path (renderer, path);
+						go_path_move_to (path, x0, y0);
+						go_path_line_to (path, x1, y1);
 					}
 					break;
 
@@ -1437,7 +1438,7 @@ axis_circle_render (GogAxisBase *axis_base, GogRenderer *renderer,
 			label_pos.y += txt_obr.y;
 			txt_obr.x = label_pos.x;
 			txt_obr.y = label_pos.y;
-			if (!first_label_done || 
+			if (!first_label_done ||
 			    (!go_geometry_test_OBR_overlap (&txt_obr, &txt_obr_old) &&
 			     !go_geometry_test_OBR_overlap (&txt_obr, &txt_obr_first))) {
 				gog_renderer_draw_text (renderer, ticks[i].label,
@@ -1450,6 +1451,9 @@ axis_circle_render (GogAxisBase *axis_base, GogRenderer *renderer,
 			}
 		}
 	}
+
+	gog_renderer_stroke_shape (renderer, path);
+	go_path_free (path);
 }
 
 static gboolean
@@ -1537,16 +1541,24 @@ xy_process (GogAxisBaseAction action, GogView *view, GogViewPadding *padding,
 
 	gog_axis_map_get_extents (a_map, &start, &stop);
 	gog_axis_map_get_bounds (a_map, &minimum, &maximum);
-	if (axis_base->position == GOG_AXIS_CROSS) {
+	side = GO_SIDE_RIGHT;
+	switch (axis_base->pos_calculated) {
+	case GOG_AXIS_CROSS :
 		position = gog_axis_base_get_cross_location (axis_base);
-		if (position < minimum || position > maximum) {
-			gog_chart_map_free (c_map);
-			return FALSE;
+		if (position < minimum)
+			position = start;
+		else if (position > maximum) {
+			position = stop;
+			side = GO_SIDE_LEFT;
 		}
-	} else
-		position = axis_base->position == GOG_AXIS_AT_LOW ?  start : stop;
-
-	side = axis_base->position == GOG_AXIS_AT_LOW ? GO_SIDE_RIGHT : GO_SIDE_LEFT;
+		break;
+	case GOG_AXIS_AT_LOW :
+		position = start;
+		break;
+	case GOG_AXIS_AT_HIGH :
+		position = stop;
+		side     = GO_SIDE_LEFT;
+	}
 
 	if (axis_type == GOG_AXIS_X) {
 		a_map = gog_chart_map_get_axis_map (c_map, 0);
@@ -1621,15 +1633,15 @@ radar_process (GogAxisBaseAction action, GogView *view, GogViewPadding *padding,
 		a_map = gog_chart_map_get_axis_map (c_map, 0);
 		gog_axis_map_get_bounds (a_map, &minimum, &maximum);
 		gog_axis_map_get_extents (a_map, &start, &stop);
-		if (axis_base->position == GOG_AXIS_CROSS) {
+		if (axis_base->pos_calculated == GOG_AXIS_CROSS) {
 			position = gog_axis_base_get_cross_location (axis_base);
 			if (position < minimum || position > maximum) {
 				gog_chart_map_free (c_map);
 				return FALSE;
 			}
 		} else
-			position = axis_base->position == GOG_AXIS_AT_LOW ?  start : stop;
-		side = axis_base->position == GOG_AXIS_AT_LOW ? GO_SIDE_RIGHT : GO_SIDE_LEFT;
+			position = axis_base->pos_calculated == GOG_AXIS_AT_LOW ?  start : stop;
+		side = axis_base->pos_calculated == GOG_AXIS_AT_LOW ? GO_SIDE_RIGHT : GO_SIDE_LEFT;
 
 		a_map = gog_chart_map_get_axis_map (c_map, 1);
 		gog_axis_map_get_extents (a_map, &start, &stop);
@@ -1725,6 +1737,9 @@ gog_axis_base_view_point (GogView *view, double x, double y)
 	gboolean pointed = FALSE;
 	GogViewAllocation const *plot_area;
 
+	if (axis_set == GOG_AXIS_SET_UNKNOWN)
+		return FALSE;
+
 	/* FIXME: not nice */
 	if (IS_GOG_AXIS (view->model))
 		plot_area = gog_chart_view_get_plot_area (view->parent);
@@ -1738,6 +1753,10 @@ gog_axis_base_view_point (GogView *view, double x, double y)
 		case GOG_AXIS_SET_XY:
 			pointed = xy_process (GOG_AXIS_BASE_POINT, view, NULL, plot_area, x, y);
 			break;
+		case GOG_AXIS_SET_XY_COLOR:
+			if (gog_axis_get_atype (axis_base->axis) != GOG_AXIS_COLOR)
+				pointed = xy_process (GOG_AXIS_BASE_POINT, view, NULL, plot_area, x, y);
+			break;
 		case GOG_AXIS_SET_XY_pseudo_3d:
 			if (gog_axis_get_atype (axis_base->axis) != GOG_AXIS_PSEUDO_3D)
 				pointed = xy_process (GOG_AXIS_BASE_POINT, view, NULL, plot_area, x, y);
@@ -1745,8 +1764,6 @@ gog_axis_base_view_point (GogView *view, double x, double y)
 		case GOG_AXIS_SET_RADAR:
 			pointed = radar_process (GOG_AXIS_BASE_POINT, view, NULL, plot_area, x, y);
 			break;
-		case GOG_AXIS_SET_UNKNOWN:
-			break;
 		default:
 			g_warning ("[AxisBaseView::point] not implemented for this axis set (%i)",
 				   axis_set);
@@ -1766,6 +1783,8 @@ gog_axis_base_view_padding_request (GogView *view, GogViewAllocation const *bbox
 	if (gog_axis_get_atype (axis_base->axis) >= GOG_AXIS_VIRTUAL)
 		return;
 	axis_set = gog_chart_get_axis_set (axis_base->chart);
+	if (axis_set == GOG_AXIS_SET_UNKNOWN)
+		return;
 
 	gog_renderer_push_style (view->renderer, style);
 
@@ -1779,8 +1798,6 @@ gog_axis_base_view_padding_request (GogView *view, GogViewAllocation const *bbox
 		case GOG_AXIS_SET_RADAR:
 			radar_process (GOG_AXIS_BASE_PADDING_REQUEST, view, padding, bbox, 0., 0.);
 			break;
-		case GOG_AXIS_SET_UNKNOWN:
-			break;
 		default:
 			g_warning ("[AxisBaseView::padding_request] not implemented for this axis set (%i)",
 				   axis_set);
@@ -1800,8 +1817,10 @@ gog_axis_base_view_render (GogView *view, GogViewAllocation const *bbox)
 
 	if (gog_axis_get_atype (axis_base->axis) >= GOG_AXIS_VIRTUAL)
 		return;
-
 	axis_set = gog_chart_get_axis_set (axis_base->chart);
+	if (axis_set == GOG_AXIS_SET_UNKNOWN)
+		return;
+
 	/* FIXME: not nice */
 	if (IS_GOG_AXIS (view->model))
 		plot_area = gog_chart_view_get_plot_area (view->parent);
@@ -1820,8 +1839,6 @@ gog_axis_base_view_render (GogView *view, GogViewAllocation const *bbox)
 		case GOG_AXIS_SET_RADAR:
 			radar_process (GOG_AXIS_BASE_RENDER, view, NULL, plot_area, 0., 0.);
 			break;
-		case GOG_AXIS_SET_UNKNOWN:
-			break;
 		default:
 			g_warning ("[AxisBaseView::render] not implemented for this axis set (%i)",
 				   axis_set);
